==> nextcloud-27.1.4.tgz: nextcloud/apps/user_status/l10n/en_GB.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Recent statuses",
    "No recent status changes" : "No recent status changes",
    "In a meeting" : "In a meeting",
    "Commuting" : "Commuting",
    "Out sick" : "Out sick",
    "Vacationing" : "Vacationing",
    "Working remotely" : "Working remotely",
    "In a call" : "In a call",
    "User status" : "User status",
    "Clear status after" : "Clear status after",
    "Emoji for your status message" : "Emoji for your status message",
    "What is your status?" : "What is your status?",
    "Predefined statuses" : "Predefined statuses",
    "Previously set" : "Previously set",
    "Reset status" : "Reset status",
    "Set status" : "Set status",
    "Online status" : "Online status",
    "Status message" : "Status message",
    "Your status was set automatically" : "Your status was set automatically",
    "Clear status message" : "Clear status message",
    "Set status message" : "Set status message",
    "Reset status to \"{icon} {message}\"" : "Reset status to \"{icon} {message}\"",
    "Reset status to \"{message}\"" : "Reset status to \"{message}\"",
    "Reset status to \"{icon}\"" : "Reset status to \"{icon}\"",
    "There was an error saving the status" : "There was an error saving the status",
    "There was an error clearing the status" : "There was an error clearing the status",
    "There was an error reverting the status" : "There was an error reverting the status",
    "Don't clear" : "Don't clear",
    "Today" : "Today",
    "This week" : "This week",
    "Online" : "Online",
    "Away" : "Away",
    "Do not disturb" : "Do not disturb",
    "Invisible" : "Invisible",
    "Offline" : "Offline",
    "There was an error saving the new status" : "There was an error saving the new status",
    "30 minutes" : "30 minutes",
    "1 hour" : "1 hour",
    "4 hours" : "4 hours",
    "Mute all notifications" : "Mute all notifications",
    "Appear offline" : "Appear offline",
    "View profile" : "View profile",
    "{status}, {timestamp}" : "{status}, {timestamp}"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.5.tgz: nextcloud/apps/user_status/l10n/en_GB.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Recent statuses",
    "No recent status changes" : "No recent status changes",
    "In a meeting" : "In a meeting",
    "Commuting" : "Commuting",
    "Out sick" : "Out sick",
    "Vacationing" : "Vacationing",
    "Out of office" : "Out of office",
    "Working remotely" : "Working remotely",
    "In a call" : "In a call",
    "User status" : "User status",
    "Clear status after" : "Clear status after",
    "Emoji for your status message" : "Emoji for your status message",
    "What is your status?" : "What is your status?",
    "Predefined statuses" : "Predefined statuses",
    "Previously set" : "Previously set",
    "Reset status" : "Reset status",
    "Set status" : "Set status",
    "Online status" : "Online status",
    "Status message" : "Status message",
    "Your status was set automatically" : "Your status was set automatically",
    "Clear status message" : "Clear status message",
    "Set status message" : "Set status message",
    "Reset status to \"{icon} {message}\"" : "Reset status to \"{icon} {message}\"",
    "Reset status to \"{message}\"" : "Reset status to \"{message}\"",
    "Reset status to \"{icon}\"" : "Reset status to \"{icon}\"",
    "There was an error saving the status" : "There was an error saving the status",
    "There was an error clearing the status" : "There was an error clearing the status",
    "There was an error reverting the status" : "There was an error reverting the status",
    "Don't clear" : "Don't clear",
    "Today" : "Today",
    "This week" : "This week",
    "Online" : "Online",
    "Away" : "Away",
    "Do not disturb" : "Do not disturb",
    "Invisible" : "Invisible",
    "Offline" : "Offline",
    "There was an error saving the new status" : "There was an error saving the new status",
    "30 minutes" : "30 minutes",
    "1 hour" : "1 hour",
    "4 hours" : "4 hours",
    "Mute all notifications" : "Mute all notifications",
    "Appear offline" : "Appear offline"
},
"nplurals=2; plural=(n != 1);");
